gtd

package module
v0.0.0-...-b8be74e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 13, 2017 License: MIT Imports: 15 Imported by: 0

README

gtd

gtd = GoToDo

gtd is simple todo list tool on CLI, written in go

Demo

gtd demo

Usage

NAME:
   gtd - todo app

USAGE:
   gtd [global options] command [command options] [arguments...]

VERSION:
   0.1.1

AUTHOR:
   Takuya Omura <t.omura8383@gmail.com>

COMMANDS:
     add, a      add todo
     list, l     list todo
     tags, t     list tags
     done, d     done todo
     clean, c    clean done todo
     delete, d   delete todo
     setting, s  edit config file
     memo, m     edit memo file associated with task (ex, gtd memo 4)
     help, h     Shows a list of commands or help for one command

GLOBAL OPTIONS:
   --help, -h     show help
   --version, -v  print the version

Installation

go get -u github.com/dais0n/gtd/cmd/gtd

Configuration

run gtd setting. this config file is made by gtd command in ${HOME}/.config/gtd/config.toml

gtdfile = "/path/to/gtd.json" # this file is todo data file. Default is in ${HOME}/gtd.json
filtercmd = "fzf" # this command is used when you type gtd add -m cmd
editor = "vim" # this editor is used by open memo file and config file
memodir = "~" # search taget below this directory when you add memo

License

MIT

Documentation

Index

Constants

const (
	ExitCodeOK        int = iota // 0
	ExitCodeError                // 1
	ExitCodeFileError            // 2

)

Variables

var Version = "0.1.1"

Functions

func Run

func Run(args []string) int

Types

type Todo

type Todo struct {
	Title    string `json:"title"`
	Done     bool   `json:"done"`
	Tag      string `json:"tag"`
	Date     string `json:"date"`
	Memo     string `json:"memo"`
	Children []Todo `json:"children"`
}

type Todos

type Todos struct {
	Todos []Todo `json:"todos"`
}

func (*Todos) SetTodos

func (todos *Todos) SetTodos(todolist []Todo)

func (*Todos) UnmarshallJson

func (todos *Todos) UnmarshallJson(path string) error

Directories

Path Synopsis
cmd
gtd command

Jump to